# kendo-ui-react-jquery-stockchart

The Kendo UI for jQuery StockChart widget wrapped as a React component.

***WARNING:*** Must install professional version of Kendo UI using credentials.

You'll need to setup a `.netrc` file on your local system. This file contains the login (username & password) of the account on telerik.com in which you purchased [Kendo UI professional](http://www.telerik.com/kendo-ui) or [DevCraft](http://www.telerik.com/devcraft).

Below are the instructions for both Windows and Mac users.

***On Windows:***

Create a text file called `\_netrc` in your home directory (e.g. `c:\users\jane\_netrc`).

Next, Declare a HOME environment variable.

EXAMPLE

```
C:\> SETX HOME %USERPROFILE%
```

Add the credentials using the format in the example above.

Git might have problems resolving your home directory if it contains spaces in its path—for example, `c:\Documents and Settings\jane`). Therefore, update your %HOME% environment variable to point to a directory having no spaces in its name.

***On Mac:***

Create a file called `.netrc` in your home directory `~/.netrc` (i.e `/User/USERNAME/.netrc`). Make sure you modify the file permissions to make it readable only to you.

Add your credentials to the `~/.netrc` (i.e `/User/USERNAME/.netrc`) file using the format from the example below.

EXAMPLE:

```
machine bower.telerik.com
    login my-telerik.identity@example.com-here
    password my-password-here
```

## Install

```bash
npm i -S kendo-ui-react-jquery-stockchart
```

## Usage Example

```javascript
import React from 'react';
import ReactDOM from 'react-dom';
import KendoStockChart from 'kendo-ui-react-jquery-stockchart';
import Kendo from 'kendo/js/kendo.core';

//Don't forget CSS, webpack used to include CSS
import 'kendo/css/web/kendo.common.min.css';
import 'kendo/css/web/kendo.default.min.css';

let dataStockChart = [{"Date":"2000/01/03","Open":41.62,"High":41.69,"Low":39.81,"Close":40.12,"Volume":2632000},{"Date":"2000/01/04","Open":39.88,"High":41.12,"Low":39.75,"Close":40.12,"Volume":3584700},{"Date":"2000/01/05","Open":42,"High":43.31,"Low":41.38,"Close":42.62,"Volume":7631700},{"Date":"2000/01/06","Open":42.25,"High":43.44,"Low":41.12,"Close":43.06,"Volume":4922200},{"Date":"2000/01/07","Open":43.88,"High":44.88,"Low":43.69,"Close":44.12,"Volume":6008300},{"Date":"2000/01/10","Open":44.31,"High":44.5,"Low":43.5,"Close":43.69,"Volume":2400000},{"Date":"2000/01/11","Open":43.38,"High":43.94,"Low":42.75,"Close":42.88,"Volume":2450200},{"Date":"2000/01/12","Open":42.75,"High":44.19,"Low":42.5,"Close":43.06,"Volume":2326900},{"Date":"2000/01/13","Open":43.31,"High":43.38,"Low":42,"Close":42.38,"Volume":3030100},{"Date":"2000/01/14","Open":43.62,"High":44.25,"Low":42.94,"Close":44,"Volume":3834900},{"Date":"2000/01/18","Open":43.88,"High":45,"Low":43.12,"Close":45,"Volume":5859100},{"Date":"2000/01/19","Open":45.38,"High":48.12,"Low":45.25,"Close":47.62,"Volume":11457600},{"Date":"2000/01/20","Open":47.56,"High":47.88,"Low":45.75,"Close":46.5,"Volume":8931100},{"Date":"2000/01/21","Open":46.94,"High":46.94,"Low":45,"Close":45.69,"Volume":4390000},{"Date":"2000/01/24","Open":45.81,"High":46.19,"Low":43.62,"Close":44.31,"Volume":3296200},{"Date":"2000/01/25","Open":45,"High":46,"Low":44.75,"Close":45.69,"Volume":5052200},{"Date":"2000/01/26","Open":45.69,"High":46.5,"Low":45,"Close":46.19,"Volume":3090100},{"Date":"2000/01/27","Open":46,"High":46.88,"Low":44.88,"Close":45.06,"Volume":3329100},{"Date":"2000/01/28","Open":44.81,"High":45.62,"Low":44.5,"Close":44.62,"Volume":2258400},{"Date":"2000/01/31","Open":44,"High":44.56,"Low":43.94,"Close":44.5,"Volume":2340500},{"Date":"2000/02/01","Open":43.88,"High":44.19,"Low":43.31,"Close":43.75,"Volume":2670800},{"Date":"2000/02/02","Open":43.38,"High":45.19,"Low":43.38,"Close":44.62,"Volume":3295500},{"Date":"2000/02/03","Open":45,"High":45.06,"Low":43.12,"Close":43.44,"Volume":2886400},{"Date":"2000/02/04","Open":43.75,"High":44.19,"Low":42.56,"Close":44,"Volume":2927200},{"Date":"2000/02/07","Open":43.88,"High":43.88,"Low":41.69,"Close":41.81,"Volume":3024400},{"Date":"2000/02/08","Open":41.94,"High":42.06,"Low":40,"Close":41,"Volume":5097700},{"Date":"2000/02/09","Open":40.25,"High":40.25,"Low":38.38,"Close":39,"Volume":5535800},{"Date":"2000/02/10","Open":38.81,"High":40.19,"Low":38.75,"Close":39.75,"Volume":4040600},{"Date":"2000/02/11","Open":39.75,"High":40.38,"Low":39.12,"Close":39.88,"Volume":3127800},{"Date":"2000/02/14","Open":39.62,"High":39.69,"Low":38.06,"Close":38.25,"Volume":2605900},{"Date":"2000/02/15","Open":38.12,"High":38.69,"Low":37.38,"Close":38.5,"Volume":3947800},{"Date":"2000/02/16","Open":37.75,"High":37.94,"Low":36.88,"Close":37.25,"Volume":3423000},{"Date":"2000/02/17","Open":37.25,"High":37.88,"Low":36.56,"Close":37.5,"Volume":3400500},{"Date":"2000/02/18","Open":37.38,"High":37.5,"Low":35.88,"Close":36,"Volume":5536500},{"Date":"2000/02/22","Open":35.94,"High":39.94,"Low":35.88,"Close":38.88,"Volume":4768400},{"Date":"2000/02/23","Open":38.62,"High":38.69,"Low":37.06,"Close":37.12,"Volume":3880800},{"Date":"2000/02/24","Open":36.88,"High":37,"Low":35.88,"Close":36.56,"Volume":4198300},{"Date":"2000/02/25","Open":37.06,"High":38,"Low":36.81,"Close":37.81,"Volume":3170600},{"Date":"2000/02/28","Open":37.5,"High":37.62,"Low":36.56,"Close":37,"Volume":3573300},{"Date":"2000/02/29","Open":37.19,"High":37.62,"Low":36.12,"Close":36.94,"Volume":3503100},{"Date":"2000/03/01","Open":36.94,"High":36.62,"Low":35.94,"Close":36.31,"Volume":2838000},{"Date":"2000/03/02","Open":35.94,"High":37.19,"Low":35.38,"Close":35.94,"Volume":4053200},{"Date":"2000/03/03","Open":35.94,"High":36.5,"Low":35.69,"Close":35.94,"Volume":3884100},{"Date":"2000/03/06","Open":35.94,"High":36.19,"Low":35,"Close":35.12,"Volume":2879500},{"Date":"2000/03/07","Open":35.12,"High":35.12,"Low":34.12,"Close":34.75,"Volume":3565000},{"Date":"2000/03/08","Open":34,"High":34.19,"Low":33.38,"Close":33.38,"Volume":4134600},{"Date":"2000/03/09","Open":33.5,"High":34.5,"Low":33.25,"Close":33.75,"Volume":3236700},{"Date":"2000/03/10","Open":33.94,"High":33.94,"Low":32.31,"Close":33.25,"Volume":5080300},{"Date":"2000/03/13","Open":32.25,"High":33.12,"Low":32,"Close":32.62,"Volume":3420200},{"Date":"2000/03/14","Open":32.75,"High":33.81,"Low":32.44,"Close":33.06,"Volume":3727900},{"Date":"2000/03/15","Open":32.88,"High":35.5,"Low":32.81,"Close":34.88,"Volume":4859300},{"Date":"2000/03/16","Open":35,"High":35.94,"Low":34.69,"Close":35.62,"Volume":4725200},{"Date":"2000/03/17","Open":37.25,"High":38.94,"Low":36,"Close":37.19,"Volume":15099400},{"Date":"2000/03/20","Open":37.19,"High":37.69,"Low":36.38,"Close":37,"Volume":5786400},{"Date":"2000/03/21","Open":37.19,"High":37.44,"Low":36.19,"Close":36.56,"Volume":4153400},{"Date":"2000/03/22","Open":36.94,"High":37.19,"Low":35.75,"Close":36.38,"Volume":3358600},{"Date":"2000/03/23","Open":35.62,"High":35.94,"Low":34.81,"Close":35.12,"Volume":4080400},{"Date":"2000/03/24","Open":36,"High":36.44,"Low":35.5,"Close":36.12,"Volume":5797400},{"Date":"2000/03/27","Open":36.25,"High":37.31,"Low":36.12,"Close":37.12,"Volume":2534000},{"Date":"2000/03/28","Open":36.94,"High":38.19,"Low":36.88,"Close":38,"Volume":5056400},{"Date":"2000/03/29","Open":37.75,"High":38.19,"Low":37.31,"Close":37.88,"Volume":2731000},{"Date":"2000/03/30","Open":37.88,"High":38.94,"Low":37.62,"Close":38.62,"Volume":3266100},{"Date":"2000/03/31","Open":38.75,"High":38.81,"Low":37.81,"Close":37.81,"Volume":4630100},{"Date":"2000/04/03","Open":37.75,"High":37.75,"Low":37.06,"Close":37.19,"Volume":3234700},{"Date":"2000/04/04","Open":37.38,"High":38.25,"Low":36.56,"Close":37.31,"Volume":4002100},{"Date":"2000/04/05","Open":36.88,"High":37.25,"Low":36,"Close":36.06,"Volume":2860900},{"Date":"2000/04/06","Open":36,"High":36.44,"Low":35.62,"Close":36.12,"Volume":2941900},{"Date":"2000/04/07","Open":36.19,"High":36.31,"Low":35.38,"Close":35.69,"Volume":2381600},{"Date":"2000/04/10","Open":35.5,"High":35.62,"Low":35,"Close":35.06,"Volume":2452600},{"Date":"2000/04/11","Open":35,"High":36.38,"Low":35,"Close":35.69,"Volume":2251100},{"Date":"2000/04/12","Open":35.94,"High":38.38,"Low":35.88,"Close":37.62,"Volume":4620200},{"Date":"2000/04/13","Open":37.62,"High":37.62,"Low":36.5,"Close":37,"Volume":2916700},{"Date":"2000/04/14","Open":36,"High":36.75,"Low":34.75,"Close":35.38,"Volume":3744900},{"Date":"2000/04/17","Open":35.12,"High":35.38,"Low":34.06,"Close":35.31,"Volume":3739100},{"Date":"2000/04/18","Open":34.62,"High":35.06,"Low":34.31,"Close":34.75,"Volume":3378800},{"Date":"2000/04/19","Open":35.94,"High":37.75,"Low":35.56,"Close":37.25,"Volume":5709000},{"Date":"2000/04/20","Open":37.5,"High":40.25,"Low":37.5,"Close":40.06,"Volume":8110700},{"Date":"2000/04/24","Open":39.62,"High":41.25,"Low":37.5,"Close":37.88,"Volume":10087700},{"Date":"2000/04/25","Open":38.25,"High":39.56,"Low":38.25,"Close":39,"Volume":5397100},{"Date":"2000/04/26","Open":39.19,"High":40.56,"Low":39,"Close":39.94,"Volume":5338300},{"Date":"2000/04/27","Open":39,"High":40.25,"Low":38.94,"Close":39.81,"Volume":3176700},{"Date":"2000/04/28","Open":39.62,"High":40.06,"Low":38.94,"Close":39.69,"Volume":1853600},{"Date":"2000/05/01","Open":39.69,"High":40.19,"Low":39,"Close":39.06,"Volume":2886100},{"Date":"2000/05/02","Open":39.06,"High":39.06,"Low":37.81,"Close":37.94,"Volume":2549200},{"Date":"2000/05/03","Open":37.31,"High":38.19,"Low":36.81,"Close":37.31,"Volume":3311300},{"Date":"2000/05/04","Open":38.25,"High":39.31,"Low":37.81,"Close":38.19,"Volume":2981100},{"Date":"2000/05/05","Open":38,"High":39.88,"Low":37.94,"Close":39.5,"Volume":2792900},{"Date":"2000/05/08","Open":39,"High":39.5,"Low":38.19,"Close":38.25,"Volume":3146400},{"Date":"2000/05/09","Open":38.5,"High":39.19,"Low":38.12,"Close":38.31,"Volume":2567300},{"Date":"2000/05/10","Open":37.75,"High":37.94,"Low":36.56,"Close":36.88,"Volume":4820400},{"Date":"2000/05/11","Open":37.12,"High":38.19,"Low":37.06,"Close":37.31,"Volume":2887200},{"Date":"2000/05/12","Open":37.62,"High":37.62,"Low":37.06,"Close":37.19,"Volume":2453200},{"Date":"2000/05/15","Open":36.62,"High":37.5,"Low":36.44,"Close":37.19,"Volume":2913500},{"Date":"2000/05/16","Open":37.19,"High":37.88,"Low":36.75,"Close":37.38,"Volume":3815700},{"Date":"2000/05/17","Open":37,"High":37.5,"Low":36.56,"Close":37.38,"Volume":2739800},{"Date":"2000/05/18","Open":37.12,"High":37.75,"Low":37.12,"Close":37.62,"Volume":2050100},{"Date":"2000/05/19","Open":37,"High":37.38,"Low":36.25,"Close":36.94,"Volume":2193900},{"Date":"2000/05/22","Open":37.38,"High":37.69,"Low":36.25,"Close":36.56,"Volume":2966000},{"Date":"2000/05/23","Open":36.62,"High":37.94,"Low":36.62,"Close":37.12,"Volume":2850600},{"Date":"2000/05/24","Open":37.25,"High":39,"Low":37.19,"Close":38.88,"Volume":4642600},{"Date":"2000/05/25","Open":38.62,"High":38.69,"Low":37.88,"Close":38.38,"Volume":3027300},{"Date":"2000/05/26","Open":38,"High":38.94,"Low":38,"Close":38.25,"Volume":2102100},{"Date":"2000/05/30","Open":38.75,"High":39.69,"Low":38.56,"Close":39.56,"Volume":2325300},{"Date":"2000/05/31","Open":39.56,"High":39.62,"Low":39,"Close":39.06,"Volume":2057000},{"Date":"2000/06/01","Open":39.56,"High":39.88,"Low":39.31,"Close":39.69,"Volume":2322400},{"Date":"2000/06/02","Open":40.06,"High":40.56,"Low":39.5,"Close":39.88,"Volume":3449500},{"Date":"2000/06/05","Open":39.12,"High":39.44,"Low":38.56,"Close":38.94,"Volume":2478000},{"Date":"2000/06/06","Open":39.19,"High":40.19,"Low":39.06,"Close":39.88,"Volume":2938800},{"Date":"2000/06/07","Open":39.69,"High":40,"Low":38.5,"Close":38.56,"Volume":2520100},{"Date":"2000/06/08","Open":38.5,"High":38.62,"Low":37.69,"Close":38.19,"Volume":2481700},{"Date":"2000/06/09","Open":38.75,"High":39.69,"Low":38.62,"Close":39.19,"Volume":2714200},{"Date":"2000/06/12","Open":38.62,"High":39.06,"Low":38.06,"Close":38.12,"Volume":1551800},{"Date":"2000/06/13","Open":38,"High":38.88,"Low":37.69,"Close":38.81,"Volume":2597400},{"Date":"2000/06/14","Open":38.5,"High":39.38,"Low":38.38,"Close":38.81,"Volume":2834500},{"Date":"2000/06/15","Open":39.5,"High":41,"Low":39.25,"Close":40.12,"Volume":6321600},{"Date":"2000/06/16","Open":40.12,"High":40.38,"Low":38.81,"Close":39.25,"Volume":4861000},{"Date":"2000/06/19","Open":39.38,"High":39.56,"Low":38.56,"Close":39,"Volume":3950100},{"Date":"2000/06/20","Open":38.88,"High":39.69,"Low":38.31,"Close":39.56,"Volume":2824900},{"Date":"2000/06/21","Open":39.44,"High":40.12,"Low":39.06,"Close":39.81,"Volume":2531000},{"Date":"2000/06/22","Open":39.75,"High":39.94,"Low":38.75,"Close":38.94,"Volume":2102400},{"Date":"2000/06/23","Open":39.5,"High":40.12,"Low":39.38,"Close":39.88,"Volume":1984700},{"Date":"2000/06/26","Open":39.5,"High":40,"Low":39.5,"Close":39.75,"Volume":2666600},{"Date":"2000/06/27","Open":39.5,"High":40.25,"Low":39.31,"Close":40,"Volume":2845500},{"Date":"2000/06/28","Open":40.38,"High":41.62,"Low":40.25,"Close":40.5,"Volume":3834100},{"Date":"2000/06/29","Open":40.69,"High":41.5,"Low":40.5,"Close":40.94,"Volume":3364100},{"Date":"2000/06/30","Open":41,"High":42.25,"Low":41,"Close":41.81,"Volume":4694200},{"Date":"2000/07/03","Open":41.62,"High":41.94,"Low":41.44,"Close":41.69,"Volume":1232300},{"Date":"2000/07/05","Open":42.12,"High":43.38,"Low":42.06,"Close":42.81,"Volume":4990900},{"Date":"2000/07/06","Open":42.88,"High":43.19,"Low":42.56,"Close":43,"Volume":3642900},{"Date":"2000/07/07","Open":43.12,"High":44.06,"Low":43.06,"Close":43.75,"Volume":4241100},{"Date":"2000/07/10","Open":43.88,"High":44,"Low":43,"Close":43,"Volume":2796200},{"Date":"2000/07/11","Open":43.12,"High":44.75,"Low":43.06,"Close":44.31,"Volume":3799200},{"Date":"2000/07/12","Open":43.94,"High":44.38,"Low":43.69,"Close":43.88,"Volume":2173800},{"Date":"2000/07/13","Open":44.12,"High":45,"Low":44.12,"Close":44.56,"Volume":3427700},{"Date":"2000/07/14","Open":44.75,"High":45.12,"Low":44.31,"Close":44.44,"Volume":3472100},{"Date":"2000/07/17","Open":44.44,"High":44.44,"Low":43.44,"Close":44,"Volume":2465200},{"Date":"2000/07/18","Open":44,"High":45.25,"Low":43.31,"Close":45.12,"Volume":4773100},{"Date":"2000/07/19","Open":45,"High":46.19,"Low":44.06,"Close":45.88,"Volume":7478900},{"Date":"2000/07/20","Open":46,"High":46.25,"Low":45.19,"Close":46.06,"Volume":5032000},{"Date":"2000/07/21","Open":46,"High":47.31,"Low":45.81,"Close":46.81,"Volume":7622000},{"Date":"2000/07/24","Open":46.69,"High":48.25,"Low":46.69,"Close":48.12,"Volume":5027400},{"Date":"2000/07/25","Open":48,"High":50.25,"Low":47.88,"Close":49.44,"Volume":8838400},{"Date":"2000/07/26","Open":49,"High":49.44,"Low":47.69,"Close":48,"Volume":5298100},{"Date":"2000/07/27","Open":48.25,"High":49.44,"Low":48.19,"Close":48.25,"Volume":3898500},{"Date":"2000/07/28","Open":48.19,"High":49.12,"Low":47.94,"Close":48.81,"Volume":3930300},{"Date":"2000/07/31","Open":48.5,"High":49.25,"Low":48.44,"Close":49,"Volume":4475100},{"Date":"2000/08/01","Open":48.88,"High":49.5,"Low":48.69,"Close":48.69,"Volume":3226800},{"Date":"2000/08/02","Open":48.88,"High":49.94,"Low":48.88,"Close":49.88,"Volume":4376200},{"Date":"2000/08/03","Open":49.56,"High":49.94,"Low":48.81,"Close":49,"Volume":3226900},{"Date":"2000/08/04","Open":49,"High":49.12,"Low":48.31,"Close":49,"Volume":2419000},{"Date":"2000/08/07","Open":48.94,"High":49.5,"Low":48.5,"Close":49.06,"Volume":2112800},{"Date":"2000/08/08","Open":48.62,"High":49.19,"Low":48.38,"Close":48.56,"Volume":3384000},{"Date":"2000/08/09","Open":48.62,"High":48.62,"Low":47.12,"Close":47.75,"Volume":4278000},{"Date":"2000/08/10","Open":47.56,"High":48.88,"Low":47.56,"Close":48.88,"Volume":2544700},{"Date":"2000/08/11","Open":48.5,"High":49.94,"Low":48.5,"Close":49.62,"Volume":3281200},{"Date":"2000/08/14","Open":49.62,"High":49.88,"Low":49.31,"Close":49.5,"Volume":2855800},{"Date":"2000/08/15","Open":48.56,"High":48.75,"Low":47.25,"Close":47.25,"Volume":3951800},{"Date":"2000/08/16","Open":46.88,"High":46.88,"Low":45.88,"Close":46.56,"Volume":6308400},{"Date":"2000/08/17","Open":45.88,"High":46.12,"Low":45.75,"Close":45.88,"Volume":2810800},{"Date":"2000/08/18","Open":45.94,"High":46.06,"Low":45.31,"Close":45.69,"Volume":4070500},{"Date":"2000/08/21","Open":45.94,"High":48.25,"Low":45.5,"Close":47.75,"Volume":4088800},{"Date":"2000/08/22","Open":47.75,"High":49.44,"Low":47.62,"Close":49.31,"Volume":4678200},{"Date":"2000/08/23","Open":48.88,"High":50.94,"Low":48.88,"Close":50.56,"Volume":6971500},{"Date":"2000/08/24","Open":50.25,"High":54,"Low":50.19,"Close":53.5,"Volume":10874700},{"Date":"2000/08/25","Open":53.5,"High":54.5,"Low":53.38,"Close":54.12,"Volume":7613400},{"Date":"2000/08/28","Open":54.12,"High":54,"Low":52.94,"Close":53.25,"Volume":4938200},{"Date":"2000/08/29","Open":52.94,"High":53.12,"Low":52.25,"Close":52.62,"Volume":3984900},{"Date":"2000/08/30","Open":52.12,"High":53,"Low":51.94,"Close":52.5,"Volume":3673400},{"Date":"2000/08/31","Open":52.25,"High":54.88,"Low":52.25,"Close":53.62,"Volume":3758200},{"Date":"2000/09/01","Open":53.81,"High":56.25,"Low":53.75,"Close":54.75,"Volume":5087500},{"Date":"2000/09/05","Open":54,"High":56.25,"Low":54,"Close":55.44,"Volume":3704900},{"Date":"2000/09/06","Open":55.62,"High":58.62,"Low":55.56,"Close":57.88,"Volume":7914100},{"Date":"2000/09/07","Open":57,"High":59.94,"Low":57,"Close":59.38,"Volume":10888800},{"Date":"2000/09/08","Open":58.62,"High":59,"Low":57.62,"Close":58.12,"Volume":6635000},{"Date":"2000/09/11","Open":57.88,"High":59.44,"Low":57.69,"Close":58.62,"Volume":4333700},{"Date":"2000/09/12","Open":58.75,"High":60.06,"Low":58.12,"Close":59,"Volume":5625100},{"Date":"2000/09/13","Open":58.88,"High":60.12,"Low":58.75,"Close":59.44,"Volume":4063800},{"Date":"2000/09/14","Open":58.88,"High":58.88,"Low":57.69,"Close":58.38,"Volume":4237000},{"Date":"2000/09/15","Open":57.88,"High":59.19,"Low":56.75,"Close":56.88,"Volume":5781200},{"Date":"2000/09/18","Open":56.75,"High":58.56,"Low":56.62,"Close":56.94,"Volume":3178700},{"Date":"2000/09/19","Open":56.62,"High":57.56,"Low":56.25,"Close":56.77,"Volume":4220300},{"Date":"2000/09/20","Open":57,"High":60.06,"Low":56.94,"Close":59.06,"Volume":6373800},{"Date":"2000/09/21","Open":59.5,"High":60.69,"Low":59.25,"Close":60.12,"Volume":6158200},{"Date":"2000/09/22","Open":59.75,"High":64.31,"Low":59,"Close":64,"Volume":6829300},{"Date":"2000/09/25","Open":63.75,"High":64.31,"Low":61.75,"Close":63.88,"Volume":5338300},{"Date":"2000/09/26","Open":63.12,"High":66.94,"Low":62.81,"Close":66.06,"Volume":7064600},{"Date":"2000/09/27","Open":65.75,"High":66.5,"Low":63.38,"Close":65.25,"Volume":7533400},{"Date":"2000/09/28","Open":63.88,"High":65.38,"Low":63.62,"Close":64.5,"Volume":6704100},{"Date":"2000/09/29","Open":62.62,"High":63.94,"Low":60.62,"Close":63.12,"Volume":5004300},{"Date":"2000/10/02","Open":61,"High":61.25,"Low":57.25,"Close":58.44,"Volume":9275500},{"Date":"2000/10/03","Open":59,"High":60.31,"Low":59,"Close":59.88,"Volume":5007200},{"Date":"2000/10/04","Open":59.5,"High":62.44,"Low":59.5,"Close":61.12,"Volume":5019900},{"Date":"2000/10/05","Open":61.06,"High":63,"Low":60.25,"Close":61.06,"Volume":4016900},{"Date":"2000/10/06","Open":61.19,"High":62.19,"Low":60.5,"Close":61,"Volume":3057100},{"Date":"2000/10/09","Open":60.25,"High":60.69,"Low":59.25,"Close":59.44,"Volume":2180100},{"Date":"2000/10/10","Open":59.62,"High":60.12,"Low":59.06,"Close":59.56,"Volume":2501200},{"Date":"2000/10/11","Open":59,"High":61.25,"Low":58.81,"Close":60.19,"Volume":2960800},{"Date":"2000/10/12","Open":59.94,"High":60.31,"Low":54,"Close":56.12,"Volume":8935400},{"Date":"2000/10/13","Open":56,"High":60.31,"Low":55.94,"Close":58.75,"Volume":4721000},{"Date":"2000/10/16","Open":59.62,"High":61.06,"Low":59.44,"Close":60.19,"Volume":2649100},{"Date":"2000/10/17","Open":60.19,"High":61.44,"Low":58.62,"Close":60.5,"Volume":2909800},{"Date":"2000/10/18","Open":58.5,"High":61.5,"Low":58.38,"Close":60.75,"Volume":4731000},{"Date":"2000/10/19","Open":61,"High":61.19,"Low":57.31,"Close":58.44,"Volume":6481600},{"Date":"2000/10/20","Open":58.38,"High":60.25,"Low":57.81,"Close":60,"Volume":3795000},{"Date":"2000/10/23","Open":60.5,"High":62,"Low":60.06,"Close":61.25,"Volume":5672500},{"Date":"2000/10/24","Open":60.88,"High":61.94,"Low":60.62,"Close":61,"Volume":4167200},{"Date":"2000/10/25","Open":61.12,"High":63.94,"Low":61.12,"Close":62.56,"Volume":5929900},{"Date":"2000/10/26","Open":62,"High":63.62,"Low":61.88,"Close":63.06,"Volume":4459800},{"Date":"2000/10/27","Open":63.06,"High":63.81,"Low":63,"Close":63.75,"Volume":2632700},{"Date":"2000/10/30","Open":63.75,"High":65.19,"Low":63.69,"Close":64.69,"Volume":4769200},{"Date":"2000/10/31","Open":64.69,"High":67.88,"Low":64.06,"Close":67.81,"Volume":4694800},{"Date":"2000/11/01","Open":67.56,"High":67.75,"Low":65.12,"Close":65.75,"Volume":5574200},{"Date":"2000/11/02","Open":65.38,"High":67,"Low":63.81,"Close":66.12,"Volume":5114500},{"Date":"2000/11/03","Open":66.19,"High":66.75,"Low":65.5,"Close":66.12,"Volume":2738700},{"Date":"2000/11/06","Open":64.44,"High":66.38,"Low":64,"Close":66,"Volume":3576700},{"Date":"2000/11/07","Open":65.5,"High":65.94,"Low":65.06,"Close":65.19,"Volume":3025800},{"Date":"2000/11/08","Open":65.19,"High":66.12,"Low":64.5,"Close":65.06,"Volume":1595500},{"Date":"2000/11/09","Open":64.88,"High":65.94,"Low":64.44,"Close":65.69,"Volume":2047300},{"Date":"2000/11/10","Open":65.44,"High":65.75,"Low":63.25,"Close":63.25,"Volume":2847400},{"Date":"2000/11/13","Open":62.12,"High":63.62,"Low":61.94,"Close":62.81,"Volume":2943400},{"Date":"2000/11/14","Open":63.06,"High":64.81,"Low":63.06,"Close":64.38,"Volume":3553800},{"Date":"2000/11/15","Open":63.75,"High":63.81,"Low":62.69,"Close":63.56,"Volume":3089800},{"Date":"2000/11/16","Open":63.56,"High":66.38,"Low":63.56,"Close":65.81,"Volume":3557400},{"Date":"2000/11/17","Open":65.75,"High":66.81,"Low":65.06,"Close":65.38,"Volume":3517000},{"Date":"2000/11/20","Open":65,"High":66.5,"Low":65,"Close":65.56,"Volume":2503900},{"Date":"2000/11/21","Open":65.31,"High":69.5,"Low":65.31,"Close":68.62,"Volume":5728600},{"Date":"2000/11/22","Open":68.12,"High":68.44,"Low":64.88,"Close":65.12,"Volume":4276000},{"Date":"2000/11/24","Open":66,"High":66.81,"Low":65.56,"Close":65.69,"Volume":1122400},{"Date":"2000/11/27","Open":67,"High":68,"Low":67,"Close":67.38,"Volume":2771400},{"Date":"2000/11/28","Open":67.31,"High":68.19,"Low":66.25,"Close":67.5,"Volume":3243900},{"Date":"2000/11/29","Open":66.44,"High":70,"Low":66.19,"Close":69.88,"Volume":6369100},{"Date":"2000/11/30","Open":69.44,"High":69.69,"Low":67.56,"Close":68.75,"Volume":4245000},{"Date":"2000/12/01","Open":68.69,"High":68.69,"Low":65.19,"Close":65.81,"Volume":4420400},{"Date":"2000/12/04","Open":65.81,"High":65.81,"Low":63.69,"Close":64.69,"Volume":5188000},{"Date":"2000/12/05","Open":65.94,"High":70.19,"Low":64.5,"Close":68.94,"Volume":6329000},{"Date":"2000/12/06","Open":68.94,"High":69.44,"Low":66.81,"Close":67.32,"Volume":4597700},{"Date":"2000/12/07","Open":67.12,"High":68.12,"Low":66.81,"Close":66.81,"Volume":2295400},{"Date":"2000/12/08","Open":67.56,"High":70.94,"Low":67.38,"Close":67.38,"Volume":5175200},{"Date":"2000/12/11","Open":69.69,"High":70.62,"Low":68.38,"Close":68.38,"Volume":3799000},{"Date":"2000/12/12","Open":68.12,"High":70.44,"Low":68.12,"Close":69.12,"Volume":3164500},{"Date":"2000/12/13","Open":68.75,"High":69.81,"Low":67.75,"Close":67.88,"Volume":2366600},{"Date":"2000/12/14","Open":67.38,"High":68.94,"Low":66.5,"Close":67.25,"Volume":3319700},{"Date":"2000/12/15","Open":65.88,"High":66.69,"Low":64.75,"Close":64.88,"Volume":6202400},{"Date":"2000/12/18","Open":66,"High":69.94,"Low":66,"Close":68.5,"Volume":4228800},{"Date":"2000/12/19","Open":67.88,"High":68.62,"Low":66.12,"Close":66.38,"Volume":4316000},{"Date":"2000/12/20","Open":66.12,"High":66.44,"Low":64.06,"Close":65,"Volume":4035600},{"Date":"2000/12/21","Open":64.75,"High":65,"Low":62.56,"Close":64.62,"Volume":4724400},{"Date":"2000/12/22","Open":64.19,"High":65,"Low":61.44,"Close":63.44,"Volume":4071700},{"Date":"2000/12/26","Open":63.88,"High":64.5,"Low":62.25,"Close":63,"Volume":2366500},{"Date":"2000/12/27","Open":62.25,"High":64.88,"Low":62.25,"Close":64.06,"Volume":2723600},{"Date":"2000/12/28","Open":64,"High":67,"Low":63.75,"Close":65.44,"Volume":2486100},{"Date":"2000/12/29","Open":65.88,"High":66.75,"Low":65.62,"Close":66,"Volume":2553400},{"Date":"2001/01/02","Open":64.88,"High":65.31,"Low":60.56,"Close":62,"Volume":3762200},{"Date":"2001/01/03","Open":60.75,"High":63.75,"Low":59.19,"Close":62.56,"Volume":6428500},{"Date":"2001/01/04","Open":64,"High":64.19,"Low":60.25,"Close":61,"Volume":3841100},{"Date":"2001/01/05","Open":61.38,"High":61.5,"Low":58.12,"Close":58.75,"Volume":3758500},{"Date":"2001/01/08","Open":58.75,"High":60.5,"Low":58.69,"Close":59,"Volume":3012100},{"Date":"2001/01/09","Open":59,"High":59,"Low":57.19,"Close":58.94,"Volume":4356700},{"Date":"2001/01/10","Open":58.38,"High":60.88,"Low":58.31,"Close":60.38,"Volume":3659600},{"Date":"2001/01/11","Open":60,"High":60.75,"Low":59,"Close":59.12,"Volume":3371000},{"Date":"2001/01/12","Open":59.56,"High":60.69,"Low":58.56,"Close":60.62,"Volume":3150700},{"Date":"2001/01/16","Open":59.94,"High":61.62,"Low":59.5,"Close":61,"Volume":3268200},{"Date":"2001/01/17","Open":62.44,"High":62.69,"Low":58.25,"Close":58.75,"Volume":6605200},{"Date":"2001/01/18","Open":56.5,"High":58,"Low":55.62,"Close":57.38,"Volume":6044500},{"Date":"2001/01/19","Open":57.38,"High":57.44,"Low":55.5,"Close":55.69,"Volume":4295900},{"Date":"2001/01/22","Open":56.31,"High":56.88,"Low":55.69,"Close":56,"Volume":3604000},{"Date":"2001/01/23","Open":56.94,"High":58,"Low":56.19,"Close":57.5,"Volume":4417100},{"Date":"2001/01/24","Open":56.88,"High":58,"Low":56.88,"Close":57.44,"Volume":2997300},{"Date":"2001/01/25","Open":56.5,"High":59.69,"Low":56.5,"Close":59.25,"Volume":3683300},{"Date":"2001/01/26","Open":58.75,"High":59.69,"Low":57.5,"Close":58.06,"Volume":2299000},{"Date":"2001/01/29","Open":57.7,"High":57.99,"Low":56.31,"Close":56.46,"Volume":2357500},{"Date":"2001/01/30","Open":56.46,"High":56.59,"Low":54.56,"Close":56.15,"Volume":3650100},{"Date":"2001/01/31","Open":56.5,"High":58.91,"Low":56.5,"Close":58.5,"Volume":3614600},{"Date":"2001/02/01","Open":58,"High":58.5,"Low":56.06,"Close":56.52,"Volume":4099000},{"Date":"2001/02/02","Open":56.97,"High":57.5,"Low":56.04,"Close":56.85,"Volume":2121700},{"Date":"2001/02/05","Open":56.73,"High":58.04,"Low":56.42,"Close":57.93,"Volume":2188100},{"Date":"2001/02/06","Open":57.88,"High":58.46,"Low":56.47,"Close":56.73,"Volume":2353100},{"Date":"2001/02/07","Open":56.95,"High":57.89,"Low":56.65,"Close":57.45,"Volume":2182900},{"Date":"2001/02/08","Open":57.35,"High":58.26,"Low":57.12,"Close":57.51,"Volume":2777000},{"Date":"2001/02/09","Open":57.7,"High":58.17,"Low":56.78,"Close":57.34,"Volume":1997200},{"Date":"2001/02/12","Open":58.65,"High":59.1,"Low":58.21,"Close":59.07,"Volume":2875500},{"Date":"2001/02/13","Open":59.09,"High":61.38,"Low":59.09,"Close":60.72,"Volume":4984900},{"Date":"2001/02/14","Open":61.72,"High":61.94,"Low":60.34,"Close":60.59,"Volume":3684200},{"Date":"2001/02/15","Open":60.59,"High":60.76,"Low":58.84,"Close":60.15,"Volume":2531900},{"Date":"2001/02/16","Open":59.8,"High":60.61,"Low":59.63,"Close":59.99,"Volume":2933600},{"Date":"2001/02/20","Open":60.35,"High":62.8,"Low":60.15,"Close":61.85,"Volume":3139500},{"Date":"2001/02/21","Open":61.85,"High":62.38,"Low":60.15,"Close":60.2,"Volume":2286300},{"Date":"2001/02/22","Open":60.2,"High":62.23,"Low":60.2,"Close":61.28,"Volume":2767600},{"Date":"2001/02/23","Open":60.98,"High":61.75,"Low":60.55,"Close":61.61,"Volume":2266900},{"Date":"2001/02/26","Open":61.45,"High":62.97,"Low":61.02,"Close":62.76,"Volume":1854600},{"Date":"2001/02/27","Open":62.3,"High":63.9,"Low":62,"Close":63.7,"Volume":2993000},{"Date":"2001/02/28","Open":63.8,"High":63.83,"Low":61.99,"Close":62.2,"Volume":3051400},{"Date":"2001/03/01","Open":61.85,"High":61.86,"Low":58.6,"Close":59.65,"Volume":4225700},{"Date":"2001/03/02","Open":59.55,"High":61.45,"Low":58.3,"Close":60.1,"Volume":3763900},{"Date":"2001/03/05","Open":59.9,"High":62.15,"Low":59.88,"Close":61.91,"Volume":2814700},{"Date":"2001/03/06","Open":62.05,"High":62.59,"Low":61.29,"Close":62.13,"Volume":2783400},{"Date":"2001/03/07","Open":61.95,"High":64.21,"Low":61.87,"Close":64.1,"Volume":3475400},{"Date":"2001/03/08","Open":64,"High":65.2,"Low":63.55,"Close":64.75,"Volume":4224600},{"Date":"2001/03/09","Open":64.45,"High":65.6,"Low":64.2,"Close":65.5,"Volume":2716600},{"Date":"2001/03/12","Open":64.2,"High":64.32,"Low":60.96,"Close":61,"Volume":4269900},{"Date":"2001/03/13","Open":62.01,"High":62.99,"Low":60.06,"Close":60.57,"Volume":4786300},{"Date":"2001/03/14","Open":59.5,"High":59.51,"Low":56.83,"Close":58.02,"Volume":5983800},{"Date":"2001/03/15","Open":58.02,"High":58.02,"Low":55.51,"Close":56.1,"Volume":5136800},{"Date":"2001/03/16","Open":55.63,"High":56.2,"Low":52.85,"Close":53.75,"Volume":10933600},{"Date":"2001/03/19","Open":54.57,"High":56.25,"Low":53.75,"Close":56.02,"Volume":6143200},{"Date":"2001/03/20","Open":56.6,"High":57.19,"Low":54.76,"Close":55,"Volume":4359800},{"Date":"2001/03/21","Open":54.6,"High":55.4,"Low":53.2,"Close":53.85,"Volume":3758400},{"Date":"2001/03/22","Open":53.1,"High":53.35,"Low":49.7,"Close":52,"Volume":6600400},{"Date":"2001/03/23","Open":52.75,"High":53.44,"Low":51.6,"Close":53,"Volume":4632300},{"Date":"2001/03/26","Open":53.55,"High":56.17,"Low":53.55,"Close":55.44,"Volume":4778800},{"Date":"2001/03/27","Open":55.31,"High":56.24,"Low":54.25,"Close":55.2,"Volume":3634200},{"Date":"2001/03/28","Open":54.6,"High":55.18,"Low":51.85,"Close":55,"Volume":2861600},{"Date":"2001/03/29","Open":54.55,"High":56.3,"Low":54.25,"Close":55.95,"Volume":2814300},{"Date":"2001/03/30","Open":55.4,"High":57.27,"Low":55.31,"Close":55.71,"Volume":3741200},{"Date":"2001/04/02","Open":55.4,"High":56.6,"Low":54.53,"Close":55.02,"Volume":3182300},{"Date":"2001/04/03","Open":55.45,"High":55.45,"Low":54.11,"Close":54.61,"Volume":3337500},{"Date":"2001/04/04","Open":54.5,"High":55.2,"Low":53.92,"Close":54.63,"Volume":2953500},{"Date":"2001/04/05","Open":56,"High":57.5,"Low":55.84,"Close":56.81,"Volume":2703000},{"Date":"2001/04/06","Open":56,"High":56.65,"Low":55.32,"Close":55.98,"Volume":2768100},{"Date":"2001/04/09","Open":56.05,"High":57.74,"Low":56,"Close":56.87,"Volume":2547300},{"Date":"2001/04/10","Open":58.1,"High":60.19,"Low":57.83,"Close":59.82,"Volume":4478700},{"Date":"2001/04/11","Open":60.57,"High":61,"Low":58.5,"Close":59.12,"Volume":3979200},{"Date":"2001/04/12","Open":58.95,"High":60.5,"Low":58.62,"Close":60.5,"Volume":1607100},{"Date":"2001/04/16","Open":60.25,"High":60.98,"Low":59.18,"Close":59.75,"Volume":2145500},{"Date":"2001/04/17","Open":59.75,"High":60.6,"Low":59,"Close":60.6,"Volume":2257400},{"Date":"2001/04/18","Open":60.85,"High":63.73,"Low":60.7,"Close":61.3,"Volume":3076500},{"Date":"2001/04/19","Open":61.48,"High":61.62,"Low":59.55,"Close":60.63,"Volume":3549200},{"Date":"2001/04/20","Open":61.9,"High":64.91,"Low":60.5,"Close":61.7,"Volume":7126900},{"Date":"2001/04/23","Open":60.9,"High":61.28,"Low":59.61,"Close":60.14,"Volume":4319700},{"Date":"2001/04/24","Open":60,"High":62.13,"Low":60,"Close":60.8,"Volume":3076600},{"Date":"2001/04/25","Open":59.95,"High":60.41,"Low":59.9,"Close":60.34,"Volume":3494100},{"Date":"2001/04/26","Open":60.09,"High":61.2,"Low":59.77,"Close":60.98,"Volume":2992200},{"Date":"2001/04/27","Open":60.92,"High":61.8,"Low":60.84,"Close":61.61,"Volume":2178600},{"Date":"2001/04/30","Open":62.4,"High":64.16,"Low":61.8,"Close":61.8,"Volume":3052800},{"Date":"2001/05/01","Open":62.7,"High":64.48,"Low":62.7,"Close":63.43,"Volume":4772100},{"Date":"2001/05/02","Open":63.68,"High":64.3,"Low":63.25,"Close":64,"Volume":3346200},{"Date":"2001/05/03","Open":63.75,"High":64.2,"Low":62.71,"Close":64,"Volume":2168500},{"Date":"2001/05/04","Open":63.15,"High":65,"Low":63,"Close":64.5,"Volume":2390700},{"Date":"2001/05/07","Open":64.7,"High":65.27,"Low":64.25,"Close":64.69,"Volume":2149200},{"Date":"2001/05/08","Open":64.5,"High":65.2,"Low":64.3,"Close":64.63,"Volume":2663000},{"Date":"2001/05/09","Open":64.05,"High":65.51,"Low":64,"Close":65,"Volume":2351300},{"Date":"2001/05/10","Open":65.55,"High":66,"Low":65.16,"Close":65.95,"Volume":2437300},{"Date":"2001/05/11","Open":65.97,"High":66.43,"Low":65.3,"Close":66.01,"Volume":1659000},{"Date":"2001/05/14","Open":66,"High":66.75,"Low":65.87,"Close":66.74,"Volume":1399700},{"Date":"2001/05/15","Open":66.02,"High":66.7,"Low":65.44,"Close":66.59,"Volume":2583000},{"Date":"2001/05/16","Open":66.6,"High":66.75,"Low":65.65,"Close":66.75,"Volume":3985800},{"Date":"2001/05/17","Open":66.75,"High":69.85,"Low":66.56,"Close":68.79,"Volume":6049300},{"Date":"2001/05/18","Open":68.79,"High":68.9,"Low":67.97,"Close":68.35,"Volume":3360700},{"Date":"2001/05/21","Open":67.9,"High":68.75,"Low":67.87,"Close":68.69,"Volume":1554000},{"Date":"2001/05/22","Open":68.1,"High":68.95,"Low":67.5,"Close":68,"Volume":2810100},{"Date":"2001/05/23","Open":67.4,"High":67.65,"Low":66,"Close":66,"Volume":3684300},{"Date":"2001/05/24","Open":66.2,"High":67.46,"Low":64.05,"Close":65.2,"Volume":4250300},{"Date":"2001/05/25","Open":64.9,"High":64.9,"Low":62.9,"Close":63.33,"Volume":3136600},{"Date":"2001/05/29","Open":63.5,"High":63.9,"Low":63.2,"Close":63.53,"Volume":2271400},{"Date":"2001/05/30","Open":63.57,"High":63.95,"Low":62.8,"Close":63.05,"Volume":3197700},{"Date":"2001/05/31","Open":63.3,"High":63.4,"Low":62.33,"Close":62.89,"Volume":2652800},{"Date":"2001/06/01","Open":63,"High":65.57,"Low":62.9,"Close":65,"Volume":3300300},{"Date":"2001/06/04","Open":64.9,"High":66.7,"Low":64.9,"Close":66.03,"Volume":2464100},{"Date":"2001/06/05","Open":67.03,"High":67.55,"Low":66.7,"Close":66.93,"Volume":3384100},{"Date":"2001/06/06","Open":66.15,"High":66.26,"Low":65.72,"Close":66.1,"Volume":3492100},{"Date":"2001/06/07","Open":65.95,"High":66.06,"Low":65.12,"Close":65.65,"Volume":2176200},{"Date":"2001/06/08","Open":65.62,"High":65.62,"Low":64.1,"Close":64.59,"Volume":2250000},{"Date":"2001/06/11","Open":64.59,"High":64.75,"Low":63.67,"Close":64.5,"Volume":1662300},{"Date":"2001/06/12","Open":64.3,"High":66.14,"Low":64.2,"Close":65.71,"Volume":3072300},{"Date":"2001/06/13","Open":65.6,"High":66.49,"Low":65.4,"Close":65.49,"Volume":2161500},{"Date":"2001/06/14","Open":65.49,"High":65.49,"Low":63.32,"Close":63.56,"Volume":3703600},{"Date":"2001/06/15","Open":63.8,"High":64.51,"Low":63.72,"Close":64.25,"Volume":5569400},{"Date":"2001/06/18","Open":64.85,"High":64.99,"Low":64.41,"Close":64.88,"Volume":2421700},{"Date":"2001/06/19","Open":64.7,"High":64.88,"Low":61.54,"Close":61.8,"Volume":4503100},{"Date":"2001/06/20","Open":61.8,"High":62.85,"Low":60.38,"Close":61.11,"Volume":5948800},{"Date":"2001/06/21","Open":60,"High":60,"Low":56.7,"Close":57.75,"Volume":9704900},{"Date":"2001/06/22","Open":57.75,"High":57.88,"Low":55.4,"Close":57,"Volume":6128000},{"Date":"2001/06/25","Open":56.95,"High":57.78,"Low":56.39,"Close":56.96,"Volume":5424700},{"Date":"2001/06/26","Open":56.7,"High":57.82,"Low":56.05,"Close":57.02,"Volume":4629500},{"Date":"2001/06/27","Open":57.02,"High":58.04,"Low":56.88,"Close":57.7,"Volume":3117600},{"Date":"2001/06/28","Open":57.3,"High":58.38,"Low":56.88,"Close":57.24,"Volume":4013600},{"Date":"2001/06/29","Open":56.89,"High":57.5,"Low":55.58,"Close":55.6,"Volume":4835700},{"Date":"2001/07/02","Open":56.6,"High":57.22,"Low":56.3,"Close":56.36,"Volume":3338500},{"Date":"2001/07/03","Open":56.36,"High":57.06,"Low":56.15,"Close":56.33,"Volume":2202300},{"Date":"2001/07/05","Open":56.7,"High":56.72,"Low":55.15,"Close":55.23,"Volume":3139100},{"Date":"2001/07/06","Open":55.05,"High":55.48,"Low":53.77,"Close":54.3,"Volume":4104200},{"Date":"2001/07/09","Open":53.85,"High":54.02,"Low":52.55,"Close":52.83,"Volume":5520600},{"Date":"2001/07/10","Open":53.73,"High":54.62,"Low":53.19,"Close":54.15,"Volume":4709600},{"Date":"2001/07/11","Open":54,"High":54.21,"Low":52.9,"Close":52.9,"Volume":3299200},{"Date":"2001/07/12","Open":53.4,"High":54.79,"Low":53.26,"Close":54.5,"Volume":3217400},{"Date":"2001/07/13","Open":54.49,"High":55.21,"Low":53.77,"Close":55.07,"Volume":1637700},{"Date":"2001/07/16","Open":54.62,"High":55.39,"Low":54.08,"Close":55.28,"Volume":1945300},{"Date":"2001/07/17","Open":55.4,"High":56.72,"Low":55.4,"Close":56.3,"Volume":3840900},{"Date":"2001/07/18","Open":57.6,"High":57.6,"Low":55.05,"Close":57.13,"Volume":5454100},{"Date":"2001/07/19","Open":57.41,"High":57.95,"Low":55.7,"Close":56.39,"Volume":3427100},{"Date":"2001/07/20","Open":56.39,"High":57.15,"Low":56.27,"Close":56.79,"Volume":1834100},{"Date":"2001/07/23","Open":57.09,"High":57.25,"Low":56.05,"Close":56.25,"Volume":2119300},{"Date":"2001/07/24","Open":56.6,"High":56.6,"Low":55.19,"Close":55.26,"Volume":2174700},{"Date":"2001/07/25","Open":55.96,"High":56.85,"Low":55.82,"Close":56.67,"Volume":1581100},{"Date":"2001/07/26","Open":56.55,"High":58.18,"Low":56.52,"Close":58.11,"Volume":2309300},{"Date":"2001/07/27","Open":57.95,"High":58.9,"Low":57.95,"Close":58.14,"Volume":2611900},{"Date":"2001/07/30","Open":58.64,"High":58.9,"Low":57.4,"Close":57.4,"Volume":2613500},{"Date":"2001/07/31","Open":57.2,"High":58.79,"Low":57.12,"Close":58.53,"Volume":2612700},{"Date":"2001/08/01","Open":58.65,"High":59.34,"Low":58.52,"Close":59,"Volume":2174400},{"Date":"2001/08/02","Open":59.5,"High":59.75,"Low":58.32,"Close":58.82,"Volume":2348200},{"Date":"2001/08/03","Open":58.82,"High":59.25,"Low":58.56,"Close":59.21,"Volume":1946300},{"Date":"2001/08/06","Open":59,"High":59.8,"Low":58.34,"Close":58.4,"Volume":2721600},{"Date":"2001/08/07","Open":57.44,"High":57.73,"Low":56.5,"Close":57.5,"Volume":4131100},{"Date":"2001/08/08","Open":57.15,"High":57.68,"Low":56.32,"Close":56.61,"Volume":2982800},{"Date":"2001/08/09","Open":56.51,"High":57.04,"Low":55.88,"Close":56.36,"Volume":3755500},{"Date":"2001/08/10","Open":56.51,"High":56.93,"Low":56.11,"Close":56.85,"Volume":2330500},{"Date":"2001/08/13","Open":56.55,"High":57.24,"Low":56.15,"Close":56.45,"Volume":1590500},{"Date":"2001/08/14","Open":56.45,"High":56.7,"Low":55.85,"Close":55.89,"Volume":2119000},{"Date":"2001/08/15","Open":55.55,"High":56.1,"Low":54.39,"Close":54.44,"Volume":3311300},{"Date":"2001/08/16","Open":54.1,"High":55.13,"Low":53.79,"Close":55.13,"Volume":2957000},{"Date":"2001/08/17","Open":55,"High":55,"Low":53.4,"Close":54,"Volume":2412300},{"Date":"2001/08/20","Open":53.75,"High":53.8,"Low":52.8,"Close":53.34,"Volume":3228000},{"Date":"2001/08/21","Open":53.27,"High":53.31,"Low":51.94,"Close":51.94,"Volume":3330300},{"Date":"2001/08/22","Open":51.94,"High":52.6,"Low":51.78,"Close":52.3,"Volume":4189500},{"Date":"2001/08/23","Open":52.1,"High":52.5,"Low":52,"Close":52.17,"Volume":1561600},{"Date":"2001/08/24","Open":52.34,"High":53.95,"Low":52.3,"Close":53.63,"Volume":2352500},{"Date":"2001/08/27","Open":53.91,"High":53.91,"Low":53.01,"Close":53.06,"Volume":1694300},{"Date":"2001/08/28","Open":53,"High":53.21,"Low":51.55,"Close":51.65,"Volume":4484300},{"Date":"2001/08/29","Open":51.8,"High":52,"Low":50.51,"Close":50.7,"Volume":3533500},{"Date":"2001/08/30","Open":50.7,"High":51.15,"Low":50.17,"Close":50.5,"Volume":2518100},{"Date":"2001/08/31","Open":50.5,"High":51.2,"Low":50.26,"Close":51.2,"Volume":1887700},{"Date":"2001/09/04","Open":49.75,"High":51.97,"Low":49.45,"Close":49.95,"Volume":3242700},{"Date":"2001/09/05","Open":50.2,"High":51.25,"Low":49.9,"Close":50.61,"Volume":3354600},{"Date":"2001/09/06","Open":50.1,"High":50.45,"Low":48.45,"Close":48.84,"Volume":3921700},{"Date":"2001/09/07","Open":47.8,"High":48,"Low":44.79,"Close":45.18,"Volume":8114600},{"Date":"2001/09/10","Open":44.9,"High":45.95,"Low":43.46,"Close":43.46,"Volume":6366000},{"Date":"2001/09/17","Open":35.65,"High":38.7,"Low":35.45,"Close":35.8,"Volume":21271800},{"Date":"2001/09/18","Open":35.8,"High":36.16,"Low":32,"Close":33.14,"Volume":16785400},{"Date":"2001/09/19","Open":32,"High":33.81,"Low":31.93,"Close":32.61,"Volume":15143500},{"Date":"2001/09/20","Open":32.03,"High":32.24,"Low":29.75,"Close":29.76,"Volume":12001700},{"Date":"2001/09/21","Open":28.25,"High":30.3,"Low":27.6,"Close":30.1,"Volume":13515700},{"Date":"2001/09/24","Open":30.09,"High":33.39,"Low":30.09,"Close":32.8,"Volume":14100500},{"Date":"2001/09/25","Open":33.25,"High":34.48,"Low":32.76,"Close":34.33,"Volume":10206200},{"Date":"2001/09/26","Open":34.55,"High":34.65,"Low":33.35,"Close":34.29,"Volume":6333100},{"Date":"2001/09/27","Open":33.9,"High":34.59,"Low":32.1,"Close":34.4,"Volume":8984400},{"Date":"2001/09/28","Open":34.41,"High":34.41,"Low":32.9,"Close":33.5,"Volume":6773200},{"Date":"2001/10/01","Open":33.5,"High":34.25,"Low":32.05,"Close":32.4,"Volume":6785800},{"Date":"2001/10/02","Open":33.48,"High":34.48,"Low":33.13,"Close":34.25,"Volume":7077600},{"Date":"2001/10/03","Open":34.51,"High":37.52,"Low":34.4,"Close":36.59,"Volume":8575200},{"Date":"2001/10/04","Open":36.59,"High":36.88,"Low":35.25,"Close":36.38,"Volume":6449600},{"Date":"2001/10/05","Open":36.5,"High":37.04,"Low":34.95,"Close":36.26,"Volume":3969300},{"Date":"2001/10/08","Open":36.2,"High":37.64,"Low":35.94,"Close":36.62,"Volume":5168500},{"Date":"2001/10/09","Open":36.9,"High":36.97,"Low":35.62,"Close":36,"Volume":3430000},{"Date":"2001/10/10","Open":36.05,"High":36.59,"Low":35.4,"Close":35.76,"Volume":4520100},{"Date":"2001/10/11","Open":35.9,"High":36.69,"Low":35.89,"Close":36.18,"Volume":5032400},{"Date":"2001/10/12","Open":36.01,"High":36.01,"Low":34.9,"Close":35.9,"Volume":5104200},{"Date":"2001/10/15","Open":35.6,"High":35.75,"Low":34.78,"Close":35.27,"Volume":4321400},{"Date":"2001/10/16","Open":35.27,"High":35.55,"Low":34.88,"Close":35.12,"Volume":3414200},{"Date":"2001/10/17","Open":35.3,"High":35.45,"Low":33.51,"Close":33.7,"Volume":4086900},{"Date":"2001/10/18","Open":33.95,"High":34.08,"Low":32.51,"Close":32.86,"Volume":5470200},{"Date":"2001/10/19","Open":33.36,"High":33.75,"Low":32.8,"Close":33.45,"Volume":3229100},{"Date":"2001/10/22","Open":33.8,"High":34.6,"Low":33.54,"Close":33.7,"Volume":3397400},{"Date":"2001/10/23","Open":34.02,"High":34.55,"Low":33.8,"Close":33.89,"Volume":3913200},{"Date":"2001/10/24","Open":34.65,"High":34.96,"Low":33.99,"Close":34.24,"Volume":3793600},{"Date":"2001/10/25","Open":34.1,"High":35.95,"Low":33.63,"Close":35.9,"Volume":5191300},{"Date":"2001/10/26","Open":36.1,"High":39.78,"Low":36.05,"Close":37.68,"Volume":11355900},{"Date":"2001/10/29","Open":35.88,"High":35.9,"Low":33.5,"Close":33.75,"Volume":9998000},{"Date":"2001/10/30","Open":33.65,"High":34.19,"Low":33.03,"Close":33.03,"Volume":5452000},{"Date":"2001/10/31","Open":33.05,"High":33.55,"Low":32.42,"Close":32.6,"Volume":4579900},{"Date":"2001/11/01","Open":32.5,"High":33.5,"Low":32.31,"Close":33.19,"Volume":4548600},{"Date":"2001/11/02","Open":33.49,"High":34.55,"Low":33.21,"Close":34.35,"Volume":4514400},{"Date":"2001/11/05","Open":35,"High":35.52,"Low":34.6,"Close":35.05,"Volume":4348800},{"Date":"2001/11/06","Open":34.9,"High":35.74,"Low":34.3,"Close":35.52,"Volume":3369400},{"Date":"2001/11/07","Open":35.23,"High":35.52,"Low":34.77,"Close":34.89,"Volume":2974200},{"Date":"2001/11/08","Open":35,"High":35.75,"Low":34.6,"Close":34.9,"Volume":2824000},{"Date":"2001/11/09","Open":35.14,"High":35.22,"Low":32.8,"Close":33.24,"Volume":13757400},{"Date":"2001/11/12","Open":33,"High":33.28,"Low":31.58,"Close":33.06,"Volume":6317800},{"Date":"2001/11/13","Open":33.95,"High":33.96,"Low":33.2,"Close":33.61,"Volume":3116300},{"Date":"2001/11/14","Open":33.95,"High":34.25,"Low":33.64,"Close":34.1,"Volume":3688900},{"Date":"2001/11/15","Open":34.1,"High":34.55,"Low":34.08,"Close":34.24,"Volume":2804800},{"Date":"2001/11/16","Open":34.8,"High":35.01,"Low":34.6,"Close":34.99,"Volume":3898100},{"Date":"2001/11/19","Open":35.01,"High":35.45,"Low":34.7,"Close":35.1,"Volume":3802300},{"Date":"2001/11/20","Open":35.2,"High":35.2,"Low":34.86,"Close":34.97,"Volume":3414800},{"Date":"2001/11/21","Open":34.97,"High":34.97,"Low":34.34,"Close":34.7,"Volume":1779400},{"Date":"2001/11/23","Open":35.09,"High":35.65,"Low":34.9,"Close":35.63,"Volume":1156100},{"Date":"2001/11/26","Open":36,"High":36.15,"Low":35.6,"Close":35.89,"Volume":3379300},{"Date":"2001/11/27","Open":36.15,"High":36.25,"Low":35.15,"Close":35.5,"Volume":3342500},{"Date":"2001/11/28","Open":35.14,"High":35.14,"Low":33.95,"Close":34.17,"Volume":3838700},{"Date":"2001/11/29","Open":34.7,"High":35.2,"Low":34.31,"Close":35.15,"Volume":3436100},{"Date":"2001/11/30","Open":34.95,"High":35.1,"Low":34.6,"Close":35.1,"Volume":3518500},{"Date":"2001/12/03","Open":35.1,"High":35.1,"Low":34.03,"Close":35,"Volume":3087700},{"Date":"2001/12/04","Open":35.01,"High":35.39,"Low":34.8,"Close":35.38,"Volume":3197400},{"Date":"2001/12/05","Open":35.5,"High":36.22,"Low":35.43,"Close":35.89,"Volume":4645300},{"Date":"2001/12/06","Open":36.18,"High":37.2,"Low":36.06,"Close":37.11,"Volume":6264700},{"Date":"2001/12/07","Open":37.4,"High":37.55,"Low":36.6,"Close":37.3,"Volume":4492300},{"Date":"2001/12/10","Open":37.32,"High":38.29,"Low":36.71,"Close":36.9,"Volume":3828600},{"Date":"2001/12/11","Open":37.2,"High":37.65,"Low":36.65,"Close":37.07,"Volume":2878600},{"Date":"2001/12/12","Open":37.3,"High":37.3,"Low":36.66,"Close":36.8,"Volume":3968200},{"Date":"2001/12/13","Open":36.45,"High":37.8,"Low":36,"Close":37,"Volume":2711200},{"Date":"2001/12/14","Open":37.15,"High":37.65,"Low":36.82,"Close":37.55,"Volume":2517400},{"Date":"2001/12/17","Open":37.35,"High":37.67,"Low":36.99,"Close":37.06,"Volume":2762900},{"Date":"2001/12/18","Open":36.6,"High":37.43,"Low":36.27,"Close":37.25,"Volume":3165600},{"Date":"2001/12/19","Open":36.35,"High":37.88,"Low":36.31,"Close":37.51,"Volume":4764900},{"Date":"2001/12/20","Open":37.85,"High":39.08,"Low":37.46,"Close":38.14,"Volume":4427600},{"Date":"2001/12/21","Open":38.4,"High":39.2,"Low":38.15,"Close":38.64,"Volume":6478500},{"Date":"2001/12/24","Open":38.54,"High":38.9,"Low":38.28,"Close":38.42,"Volume":1155500},{"Date":"2001/12/26","Open":38.45,"High":38.85,"Low":38.16,"Close":38.6,"Volume":1958700},{"Date":"2001/12/27","Open":38.73,"High":38.84,"Low":38.55,"Close":38.69,"Volume":2167200},{"Date":"2001/12/28","Open":38.93,"High":39.12,"Low":38.69,"Close":39.1,"Volume":2348100},{"Date":"2001/12/31","Open":39.19,"High":39.42,"Low":38.78,"Close":38.78,"Volume":2285800},{"Date":"2002/01/02","Open":38.54,"High":38.67,"Low":37.85,"Close":38.1,"Volume":3522900},{"Date":"2002/01/03","Open":38.4,"High":39,"Low":38.32,"Close":38.75,"Volume":3491400},{"Date":"2002/01/04","Open":39.65,"High":40.4,"Low":39.42,"Close":40.36,"Volume":4080300},{"Date":"2002/01/07","Open":41,"High":41.89,"Low":40.92,"Close":41,"Volume":6092300},{"Date":"2002/01/08","Open":41.47,"High":41.7,"Low":40.02,"Close":40.33,"Volume":4152500},{"Date":"2002/01/09","Open":40.39,"High":40.89,"Low":39.5,"Close":39.9,"Volume":4573100},{"Date":"2002/01/10","Open":40.1,"High":40.25,"Low":39.63,"Close":39.84,"Volume":2652700},{"Date":"2002/01/11","Open":39.84,"High":39.95,"Low":38.6,"Close":38.69,"Volume":3394800},{"Date":"2002/01/14","Open":38.69,"High":38.7,"Low":38.07,"Close":38.25,"Volume":2717400},{"Date":"2002/01/15","Open":38.6,"High":39.49,"Low":38.43,"Close":39.35,"Volume":3240000},{"Date":"2002/01/16","Open":38.65,"High":39.1,"Low":38.02,"Close":38.02,"Volume":3780700},{"Date":"2002/01/17","Open":38.55,"High":38.67,"Low":37.65,"Close":38.33,"Volume":3090700},{"Date":"2002/01/18","Open":38.33,"High":39.62,"Low":38.03,"Close":39.15,"Volume":2804100},{"Date":"2002/01/22","Open":39.7,"High":39.92,"Low":39.27,"Close":39.78,"Volume":2796100},{"Date":"2002/01/23","Open":40.06,"High":40.83,"Low":38,"Close":39.33,"Volume":8881400},{"Date":"2002/01/24","Open":39.6,"High":40.25,"Low":39.4,"Close":40,"Volume":5631300},{"Date":"2002/01/25","Open":40.03,"High":40.48,"Low":39.74,"Close":40.48,"Volume":3083400},{"Date":"2002/01/28","Open":40.72,"High":41,"Low":40.34,"Close":40.9,"Volume":2003600},{"Date":"2002/01/29","Open":41.17,"High":41.29,"Low":40.09,"Close":40.23,"Volume":2634800},{"Date":"2002/01/30","Open":39.85,"High":40.44,"Low":39.05,"Close":40,"Volume":3214200},{"Date":"2002/01/31","Open":40.05,"High":40.95,"Low":39.87,"Close":40.95,"Volume":4355800},{"Date":"2002/02/01","Open":41,"High":41.65,"Low":40.9,"Close":41.46,"Volume":4728700},{"Date":"2002/02/04","Open":41.55,"High":41.81,"Low":40.8,"Close":41.1,"Volume":4485700},{"Date":"2002/02/05","Open":40.85,"High":41.49,"Low":40.5,"Close":40.9,"Volume":3250700},{"Date":"2002/02/06","Open":40.73,"High":41.5,"Low":40.56,"Close":40.98,"Volume":3332900},{"Date":"2002/02/07","Open":41.17,"High":41.46,"Low":40.96,"Close":41.06,"Volume":2139500},{"Date":"2002/02/08","Open":41.05,"High":41.9,"Low":40.81,"Close":41.7,"Volume":2555000},{"Date":"2002/02/11","Open":41.9,"High":43.2,"Low":41.72,"Close":43,"Volume":3962900},{"Date":"2002/02/12","Open":42.75,"High":43.35,"Low":42.61,"Close":43.15,"Volume":4440300},{"Date":"2002/02/13","Open":43.6,"High":44.99,"Low":43.52,"Close":44.9,"Volume":5587400},{"Date":"2002/02/14","Open":44.7,"High":44.8,"Low":44,"Close":44.77,"Volume":3109300},{"Date":"2002/02/15","Open":44.77,"High":45.01,"Low":44.36,"Close":44.9,"Volume":3744900},{"Date":"2002/02/19","Open":44.1,"High":44.13,"Low":43.4,"Close":43.71,"Volume":4567200},{"Date":"2002/02/20","Open":43.8,"High":43.95,"Low":42.55,"Close":43.31,"Volume":4338000},{"Date":"2002/02/21","Open":43.25,"High":45.1,"Low":43.2,"Close":44.21,"Volume":4993600},{"Date":"2002/02/22","Open":43.87,"High":45.07,"Low":43.37,"Close":44.76,"Volume":4148600},{"Date":"2002/02/25","Open":44.75,"High":45,"Low":43.9,"Close":44.94,"Volume":3309100},{"Date":"2002/02/26","Open":44.74,"High":45.46,"Low":44.25,"Close":45.15,"Volume":3875600},{"Date":"2002/02/27","Open":45.65,"High":46.87,"Low":45.42,"Close":45.9,"Volume":4202400},{"Date":"2002/02/28","Open":46.01,"High":47.47,"Low":45.9,"Close":45.96,"Volume":4078800},{"Date":"2002/03/01","Open":46.55,"High":47.84,"Low":46.5,"Close":47.84,"Volume":3934000},{"Date":"2002/03/04","Open":48,"High":49.54,"Low":47.9,"Close":49.13,"Volume":3730200},{"Date":"2002/03/05","Open":49.1,"High":49.1,"Low":47.41,"Close":48.21,"Volume":3583800},{"Date":"2002/03/06","Open":48.22,"High":49.86,"Low":47.74,"Close":49.86,"Volume":3689600},{"Date":"2002/03/07","Open":49.8,"High":50,"Low":47.5,"Close":48.48,"Volume":3820600},{"Date":"2002/03/08","Open":49.5,"High":49.89,"Low":48.93,"Close":49.4,"Volume":4340100},{"Date":"2002/03/11","Open":49.4,"High":51.07,"Low":49.05,"Close":50.88,"Volume":4616000},{"Date":"2002/03/12","Open":49.88,"High":50.48,"Low":49.45,"Close":50.28,"Volume":4087500},{"Date":"2002/03/13","Open":50.18,"High":50.25,"Low":48.9,"Close":49.22,"Volume":3410300},{"Date":"2002/03/14","Open":49.23,"High":49.23,"Low":47.34,"Close":47.61,"Volume":5417600},{"Date":"2002/03/15","Open":47.68,"High":47.99,"Low":46.41,"Close":47.98,"Volume":6354200},{"Date":"2002/03/18","Open":48.27,"High":48.44,"Low":46.77,"Close":47.63,"Volume":3091100},{"Date":"2002/03/19","Open":47.63,"High":48.25,"Low":47.22,"Close":48.04,"Volume":2764200},{"Date":"2002/03/20","Open":47.6,"High":47.65,"Low":46.9,"Close":47.03,"Volume":2385500},{"Date":"2002/03/21","Open":46.73,"High":47.85,"Low":46.11,"Close":47.67,"Volume":2972100},{"Date":"2002/03/22","Open":47,"High":47.25,"Low":46.12,"Close":46.39,"Volume":2973100},{"Date":"2002/03/25","Open":46.2,"High":46.85,"Low":45.25,"Close":45.72,"Volume":2528400},{"Date":"2002/03/26","Open":45.85,"High":46.65,"Low":45.54,"Close":45.79,"Volume":2276100},{"Date":"2002/03/27","Open":46.05,"High":47.76,"Low":46.05,"Close":47.33,"Volume":4900900},{"Date":"2002/03/28","Open":47.57,"High":48.72,"Low":47.5,"Close":48.25,"Volume":4074500},{"Date":"2002/04/01","Open":48.25,"High":48.75,"Low":47.8,"Close":47.92,"Volume":2992400},{"Date":"2002/04/02","Open":47.92,"High":49.55,"Low":47.62,"Close":49.09,"Volume":3423300},{"Date":"2002/04/03","Open":48.65,"High":49.85,"Low":48.56,"Close":48.73,"Volume":4746700},{"Date":"2002/04/04","Open":48.73,"High":49.5,"Low":48.56,"Close":49.08,"Volume":2656100},{"Date":"2002/04/05","Open":49.45,"High":49.68,"Low":47.4,"Close":48.29,"Volume":2653600},{"Date":"2002/04/08","Open":47.9,"High":49.12,"Low":47.59,"Close":49,"Volume":2403100},{"Date":"2002/04/09","Open":49,"High":49.14,"Low":48.3,"Close":48.57,"Volume":2181400},{"Date":"2002/04/10","Open":48.57,"High":49.73,"Low":48.39,"Close":49.58,"Volume":3427000},{"Date":"2002/04/11","Open":49.8,"High":50.05,"Low":48.6,"Close":48.82,"Volume":3752600},{"Date":"2002/04/12","Open":49.25,"High":49.29,"Low":48.23,"Close":48.55,"Volume":2058600},{"Date":"2002/04/15","Open":48.2,"High":48.45,"Low":47.53,"Close":47.65,"Volume":2009400},{"Date":"2002/04/16","Open":48.45,"High":48.98,"Low":48.19,"Close":48.7,"Volume":2103100},{"Date":"2002/04/17","Open":47.55,"High":47.56,"Low":45,"Close":45.37,"Volume":10675700},{"Date":"2002/04/18","Open":45.38,"High":45.38,"Low":41.99,"Close":43.7,"Volume":16715600},{"Date":"2002/04/19","Open":44.06,"High":44.3,"Low":42.74,"Close":42.75,"Volume":8422000},{"Date":"2002/04/22","Open":42.8,"High":43.38,"Low":42.4,"Close":43.14,"Volume":4344100},{"Date":"2002/04/23","Open":43.19,"High":43.77,"Low":42,"Close":42.5,"Volume":5396700},{"Date":"2002/04/24","Open":42.9,"High":43.23,"Low":42.35,"Close":42.4,"Volume":3300700},{"Date":"2002/04/25","Open":42.25,"High":43,"Low":41,"Close":41.9,"Volume":4282200},{"Date":"2002/04/26","Open":42,"High":42.46,"Low":41.3,"Close":41.51,"Volume":2737800},{"Date":"2002/04/29","Open":43.7,"High":43.99,"Low":43.1,"Close":43.63,"Volume":6449000},{"Date":"2002/04/30","Open":43.8,"High":45.73,"Low":43.48,"Close":44.6,"Volume":5494700},{"Date":"2002/05/01","Open":44.9,"High":45.5,"Low":43.83,"Close":45.5,"Volume":4285600},{"Date":"2002/05/02","Open":45.49,"High":45.5,"Low":44.48,"Close":44.87,"Volume":2616800},{"Date":"2002/05/03","Open":44.67,"High":45.1,"Low":43.85,"Close":44.63,"Volume":2112400},{"Date":"2002/05/06","Open":45,"High":45.21,"Low":43.33,"Close":43.38,"Volume":2513100},{"Date":"2002/05/07","Open":43.6,"High":43.85,"Low":42.8,"Close":43.14,"Volume":3436300},{"Date":"2002/05/08","Open":43.3,"High":44.74,"Low":43.3,"Close":44.41,"Volume":2813100},{"Date":"2002/05/09","Open":44.6,"High":45.24,"Low":44.5,"Close":44.98,"Volume":2394600},{"Date":"2002/05/10","Open":44.4,"High":44.75,"Low":43.55,"Close":43.63,"Volume":4259500},{"Date":"2002/05/13","Open":43.9,"High":44.62,"Low":43.76,"Close":44.28,"Volume":2399300},{"Date":"2002/05/14","Open":45.58,"High":45.74,"Low":44.64,"Close":45.48,"Volume":3425900},{"Date":"2002/05/15","Open":45.38,"High":45.38,"Low":44.51,"Close":44.55,"Volume":2203300},{"Date":"2002/05/16","Open":44.85,"High":45.18,"Low":44.52,"Close":45,"Volume":2251700},{"Date":"2002/05/17","Open":45.23,"High":45.61,"Low":44.8,"Close":45.42,"Volume":2417300},{"Date":"2002/05/20","Open":45.64,"High":46.03,"Low":44.87,"Close":45.13,"Volume":2434400},{"Date":"2002/05/21","Open":45.14,"High":45.75,"Low":44.11,"Close":44.35,"Volume":2587200},{"Date":"2002/05/22","Open":44.25,"High":44.59,"Low":43.29,"Close":44.41,"Volume":2428900},{"Date":"2002/05/23","Open":43.83,"High":44.5,"Low":43.39,"Close":44.15,"Volume":2621600},{"Date":"2002/05/24","Open":44,"High":44,"Low":43.07,"Close":43.35,"Volume":2197100},{"Date":"2002/05/28","Open":43.35,"High":43.35,"Low":42.75,"Close":43,"Volume":2420500},{"Date":"2002/05/29","Open":42.7,"High":43.5,"Low":42.65,"Close":43,"Volume":2907800},{"Date":"2002/05/30","Open":42.6,"High":44.19,"Low":42.46,"Close":43.66,"Volume":3061400},{"Date":"2002/05/31","Open":43.82,"High":44.09,"Low":42.65,"Close":42.65,"Volume":2468600},{"Date":"2002/06/03","Open":43.4,"High":43.87,"Low":41.83,"Close":41.86,"Volume":2895000},{"Date":"2002/06/04","Open":41.87,"High":42.4,"Low":41.45,"Close":41.85,"Volume":2711300},{"Date":"2002/06/05","Open":42.1,"High":42.79,"Low":41.87,"Close":42.54,"Volume":1635700},{"Date":"2002/06/06","Open":42.54,"High":42.77,"Low":41.92,"Close":41.96,"Volume":1760700},{"Date":"2002/06/07","Open":41.96,"High":43.25,"Low":41.75,"Close":42.76,"Volume":2985900},{"Date":"2002/06/10","Open":42.95,"High":43.5,"Low":42.83,"Close":42.92,"Volume":1846000},{"Date":"2002/06/11","Open":43.1,"High":43.8,"Low":42.3,"Close":42.5,"Volume":1812200},{"Date":"2002/06/12","Open":42.62,"High":43.99,"Low":42.6,"Close":43.83,"Volume":2173800},{"Date":"2002/06/13","Open":43.3,"High":43.75,"Low":42.39,"Close":42.5,"Volume":2378700},{"Date":"2002/06/14","Open":42.75,"High":43,"Low":41.78,"Close":42.53,"Volume":2527200},{"Date":"2002/06/17","Open":42.54,"High":44.35,"Low":42.54,"Close":44,"Volume":3016900},{"Date":"2002/06/18","Open":43.95,"High":44.28,"Low":43.4,"Close":43.78,"Volume":1957900},{"Date":"2002/06/19","Open":43.47,"High":44.1,"Low":43.1,"Close":43.13,"Volume":1963600},{"Date":"2002/06/20","Open":43.13,"High":44.49,"Low":43.02,"Close":43.77,"Volume":2661300},{"Date":"2002/06/21","Open":43.03,"High":43.72,"Low":42.74,"Close":42.97,"Volume":3605100},{"Date":"2002/06/24","Open":42.92,"High":43.67,"Low":41.52,"Close":42.74,"Volume":3733000},{"Date":"2002/06/25","Open":43.3,"High":44.12,"Low":42.82,"Close":42.87,"Volume":3937100},{"Date":"2002/06/26","Open":41.87,"High":43.1,"Low":41.87,"Close":42.72,"Volume":3360100},{"Date":"2002/06/27","Open":43,"High":44.88,"Low":42.96,"Close":44.8,"Volume":3373600},{"Date":"2002/06/28","Open":44.35,"High":45.09,"Low":44.1,"Close":45,"Volume":5535800},{"Date":"2002/07/01","Open":44.97,"High":45.28,"Low":44.56,"Close":44.6,"Volume":3473800},{"Date":"2002/07/02","Open":44.4,"High":44.78,"Low":43.86,"Close":44.54,"Volume":2874400},{"Date":"2002/07/03","Open":44.14,"High":44.45,"Low":43.17,"Close":43.77,"Volume":3029300},{"Date":"2002/07/05","Open":44.2,"High":45.2,"Low":44.05,"Close":45,"Volume":1805700},{"Date":"2002/07/08","Open":44.72,"High":45.09,"Low":43.87,"Close":44.1,"Volume":2689400},{"Date":"2002/07/09","Open":43.99,"High":44.69,"Low":43.09,"Close":43.22,"Volume":2621800},{"Date":"2002/07/10","Open":43.52,"High":43.7,"Low":40.46,"Close":40.8,"Volume":6563000},{"Date":"2002/07/11","Open":40.8,"High":41.47,"Low":39.55,"Close":41.17,"Volume":5690400},{"Date":"2002/07/12","Open":41.24,"High":41.49,"Low":39.13,"Close":40.15,"Volume":3220000},{"Date":"2002/07/15","Open":39.85,"High":39.87,"Low":37.2,"Close":39.76,"Volume":5180900},{"Date":"2002/07/16","Open":40.05,"High":41.8,"Low":40.05,"Close":40.87,"Volume":5418600},{"Date":"2002/07/17","Open":42.42,"High":43.19,"Low":42.15,"Close":42.94,"Volume":6335600},{"Date":"2002/07/18","Open":43.09,"High":43.1,"Low":41.23,"Close":41.29,"Volume":3626000},{"Date":"2002/07/19","Open":40.89,"High":41,"Low":39.56,"Close":39.92,"Volume":4253700},{"Date":"2002/07/22","Open":39.8,"High":40.15,"Low":37.58,"Close":38.53,"Volume":5662600},{"Date":"2002/07/23","Open":38.45,"High":39.9,"Low":38.1,"Close":38.85,"Volume":5560500},{"Date":"2002/07/24","Open":37.5,"High":41.37,"Low":37.1,"Close":41.19,"Volume":5493500},{"Date":"2002/07/25","Open":41,"High":42.94,"Low":40.31,"Close":42.94,"Volume":5133200},{"Date":"2002/07/26","Open":42.5,"High":42.51,"Low":40.14,"Close":42,"Volume":3374000},{"Date":"2002/07/29","Open":42.94,"High":42.99,"Low":41.3,"Close":42.03,"Volume":5595200},{"Date":"2002/07/30","Open":41.99,"High":42,"Low":40.6,"Close":41.65,"Volume":5201100},{"Date":"2002/07/31","Open":41.66,"High":41.66,"Low":40.35,"Close":41.52,"Volume":4391400},{"Date":"2002/08/01","Open":41,"High":41.4,"Low":40.35,"Close":40.63,"Volume":3361300},{"Date":"2002/08/02","Open":40.63,"High":40.86,"Low":39.1,"Close":39.85,"Volume":2931400},{"Date":"2002/08/05","Open":39.65,"High":40.27,"Low":38.53,"Close":38.61,"Volume":3146300},{"Date":"2002/08/06","Open":39.01,"High":40.59,"Low":39.01,"Close":39.41,"Volume":3075500},{"Date":"2002/08/07","Open":39.85,"High":41.13,"Low":39.7,"Close":41.1,"Volume":3484000},{"Date":"2002/08/08","Open":41,"High":41.6,"Low":40.25,"Close":41.5,"Volume":3806300},{"Date":"2002/08/09","Open":41.1,"High":41.65,"Low":40.41,"Close":41,"Volume":3368000},{"Date":"2002/08/12","Open":40.15,"High":40.65,"Low":39.55,"Close":40.5,"Volume":2868700},{"Date":"2002/08/13","Open":39.9,"High":39.91,"Low":37.1,"Close":37.23,"Volume":9540500},{"Date":"2002/08/14","Open":36.83,"High":36.84,"Low":34.1,"Close":36.35,"Volume":12105500},{"Date":"2002/08/15","Open":36.35,"High":37.95,"Low":35.4,"Close":37.49,"Volume":7548300},{"Date":"2002/08/16","Open":38.19,"High":38.4,"Low":36.99,"Close":37.5,"Volume":4649600},{"Date":"2002/08/19","Open":37.51,"High":38.56,"Low":37.41,"Close":38.5,"Volume":3630800},{"Date":"2002/08/20","Open":38.57,"High":38.57,"Low":37.73,"Close":37.88,"Volume":2990800},{"Date":"2002/08/21","Open":38,"High":38.43,"Low":36.91,"Close":37.57,"Volume":2993700},{"Date":"2002/08/22","Open":37.6,"High":38.65,"Low":37.26,"Close":38.5,"Volume":2855900},{"Date":"2002/08/23","Open":38.5,"High":38.5,"Low":36.9,"Close":37.13,"Volume":3583400},{"Date":"2002/08/26","Open":37.13,"High":37.27,"Low":35.85,"Close":36.89,"Volume":3004700},{"Date":"2002/08/27","Open":37.1,"High":37.69,"Low":36.59,"Close":37.03,"Volume":2874400},{"Date":"2002/08/28","Open":37.03,"High":37.85,"Low":36.4,"Close":37.53,"Volume":4112100},{"Date":"2002/08/29","Open":36.73,"High":37.8,"Low":36.35,"Close":37.17,"Volume":3606800},{"Date":"2002/08/30","Open":36.93,"High":37.7,"Low":36.7,"Close":37.07,"Volume":2062500},{"Date":"2002/09/03","Open":36.8,"High":36.85,"Low":35.23,"Close":35.46,"Volume":3485200},{"Date":"2002/09/04","Open":35.5,"High":37.06,"Low":35.25,"Close":36.85,"Volume":2833200},{"Date":"2002/09/05","Open":36.45,"High":36.95,"Low":36,"Close":36.03,"Volume":2968800},{"Date":"2002/09/06","Open":36.58,"High":37.65,"Low":36.54,"Close":37.21,"Volume":2379000},{"Date":"2002/09/09","Open":37.21,"High":37.76,"Low":36.5,"Close":37.35,"Volume":3121700},{"Date":"2002/09/10","Open":37.3,"High":37.78,"Low":36.55,"Close":37.18,"Volume":2615400},{"Date":"2002/09/11","Open":37.43,"High":37.8,"Low":36.92,"Close":37.08,"Volume":2468400},{"Date":"2002/09/12","Open":36.88,"High":37.11,"Low":36.35,"Close":36.45,"Volume":2886600},{"Date":"2002/09/13","Open":35.87,"High":36.17,"Low":35.01,"Close":35.58,"Volume":3558500},{"Date":"2002/09/16","Open":35.9,"High":37.41,"Low":35.9,"Close":37.23,"Volume":3265400},{"Date":"2002/09/17","Open":37.4,"High":37.6,"Low":36.07,"Close":36.29,"Volume":3776900},{"Date":"2002/09/18","Open":36.09,"High":37.15,"Low":36.01,"Close":36.77,"Volume":3418300},{"Date":"2002/09/19","Open":36,"High":36.7,"Low":35.45,"Close":35.52,"Volume":3089900},{"Date":"2002/09/20","Open":35.9,"High":36.75,"Low":35.65,"Close":36.48,"Volume":5040400},{"Date":"2002/09/23","Open":35.9,"High":36,"Low":34.86,"Close":35.4,"Volume":3624000},{"Date":"2002/09/24","Open":35.12,"High":35.7,"Low":34.65,"Close":34.96,"Volume":3649300},{"Date":"2002/09/25","Open":35.1,"High":35.5,"Low":34.5,"Close":35.41,"Volume":3632600},{"Date":"2002/09/26","Open":35.81,"High":36.59,"Low":35.56,"Close":36.55,"Volume":2328100},{"Date":"2002/09/27","Open":36.3,"High":36.3,"Low":34.66,"Close":34.7,"Volume":3478400},{"Date":"2002/09/30","Open":34.4,"High":34.82,"Low":33.2,"Close":34.13,"Volume":4072100},{"Date":"2002/10/01","Open":34.32,"High":36.02,"Low":34.25,"Close":36,"Volume":3355500},{"Date":"2002/10/02","Open":35.5,"High":35.5,"Low":34.13,"Close":34.38,"Volume":2953900},{"Date":"2002/10/03","Open":34.78,"High":35.3,"Low":34.19,"Close":34.31,"Volume":3650900},{"Date":"2002/10/04","Open":34.32,"High":34.32,"Low":31.95,"Close":32.01,"Volume":7042100},{"Date":"2002/10/07","Open":32.22,"High":32.9,"Low":31.63,"Close":32.38,"Volume":4367000},{"Date":"2002/10/08","Open":33,"High":33.01,"Low":31.18,"Close":32.01,"Volume":4234800},{"Date":"2002/10/09","Open":31.4,"High":31.75,"Low":29.95,"Close":30.44,"Volume":6260300},{"Date":"2002/10/10","Open":30.3,"High":31.7,"Low":29.98,"Close":31.35,"Volume":4582900},{"Date":"2002/10/11","Open":31.75,"High":32.65,"Low":31.34,"Close":32,"Volume":4082700},{"Date":"2002/10/14","Open":30.3,"High":31.35,"Low":30.25,"Close":31.06,"Volume":5319100},{"Date":"2002/10/15","Open":31.27,"High":32.41,"Low":31.14,"Close":32.15,"Volume":4654900},{"Date":"2002/10/16","Open":32.16,"High":32.52,"Low":30.27,"Close":30.5,"Volume":7269100},{"Date":"2002/10/17","Open":30.75,"High":31,"Low":29.46,"Close":29.98,"Volume":8574300},{"Date":"2002/10/18","Open":29.25,"High":29.45,"Low":28.53,"Close":29,"Volume":7013300},{"Date":"2002/10/21","Open":29,"High":30.5,"Low":28.58,"Close":30.36,"Volume":5950400},{"Date":"2002/10/22","Open":29.98,"High":30.28,"Low":29.55,"Close":30.14,"Volume":4025700},{"Date":"2002/10/23","Open":29.97,"High":30.71,"Low":29.88,"Close":30.7,"Volume":3164300},{"Date":"2002/10/24","Open":30.87,"High":31.2,"Low":29.7,"Close":29.95,"Volume":4017600},{"Date":"2002/10/25","Open":29.99,"High":30.35,"Low":29.35,"Close":30.32,"Volume":3336200},{"Date":"2002/10/28","Open":30.42,"High":30.8,"Low":28.7,"Close":28.98,"Volume":5205300},{"Date":"2002/10/29","Open":28.9,"High":29.9,"Low":28.54,"Close":29.7,"Volume":4090100},{"Date":"2002/10/30","Open":29.77,"High":30.39,"Low":29.2,"Close":30.2,"Volume":3078200},{"Date":"2002/10/31","Open":30.4,"High":30.52,"Low":29.55,"Close":29.75,"Volume":2865900},{"Date":"2002/11/01","Open":29.79,"High":30.65,"Low":29.56,"Close":30.4,"Volume":2939600},{"Date":"2002/11/04","Open":30.41,"High":30.86,"Low":29.63,"Close":29.67,"Volume":4919500},{"Date":"2002/11/05","Open":29.87,"High":31.98,"Low":29.87,"Close":31.52,"Volume":4739100},{"Date":"2002/11/06","Open":32.04,"High":33.88,"Low":32.01,"Close":33.58,"Volume":8651500},{"Date":"2002/11/07","Open":33.78,"High":33.9,"Low":32.11,"Close":32.29,"Volume":4371900},{"Date":"2002/11/08","Open":32.85,"High":33.6,"Low":32.5,"Close":33.18,"Volume":4239700},{"Date":"2002/11/11","Open":33.18,"High":33.21,"Low":31,"Close":31.23,"Volume":3686300},{"Date":"2002/11/12","Open":31.8,"High":32.1,"Low":31.25,"Close":31.66,"Volume":4498300},{"Date":"2002/11/13","Open":31.63,"High":32.27,"Low":30.87,"Close":31.42,"Volume":3351400},{"Date":"2002/11/14","Open":32.1,"High":32.4,"Low":30.87,"Close":31.35,"Volume":3079800},{"Date":"2002/11/15","Open":31.35,"High":32,"Low":31.04,"Close":31.5,"Volume":2634400},{"Date":"2002/11/18","Open":31.54,"High":31.78,"Low":30.9,"Close":30.92,"Volume":3389900},{"Date":"2002/11/19","Open":31.02,"High":31.65,"Low":30.62,"Close":31.4,"Volume":3510600},{"Date":"2002/11/20","Open":32.1,"High":32.24,"Low":31.2,"Close":31.73,"Volume":3401500},{"Date":"2002/11/21","Open":32.2,"High":33.02,"Low":32.02,"Close":32.44,"Volume":5257200},{"Date":"2002/11/22","Open":32.69,"High":34.43,"Low":32.69,"Close":34,"Volume":5475800},{"Date":"2002/11/25","Open":34.38,"High":34.7,"Low":33.2,"Close":33.49,"Volume":3167400},{"Date":"2002/11/26","Open":33.7,"High":34.05,"Low":33.26,"Close":33.67,"Volume":3133600},{"Date":"2002/11/27","Open":33.53,"High":35.14,"Low":33.53,"Close":35.02,"Volume":3802900},{"Date":"2002/11/29","Open":35.03,"High":35.03,"Low":33.8,"Close":34.05,"Volume":2375900},{"Date":"2002/12/02","Open":34.6,"High":34.88,"Low":33.7,"Close":34.1,"Volume":2625200},{"Date":"2002/12/03","Open":34.49,"High":34.5,"Low":33.75,"Close":34.24,"Volume":2868700},{"Date":"2002/12/04","Open":33.77,"High":34.38,"Low":33.56,"Close":33.93,"Volume":2646900},{"Date":"2002/12/05","Open":33.75,"High":33.76,"Low":32.43,"Close":32.96,"Volume":3851900},{"Date":"2002/12/06","Open":32.4,"High":33.75,"Low":32.23,"Close":33.4,"Volume":3698900},{"Date":"2002/12/09","Open":32.63,"High":33.25,"Low":32.31,"Close":32.4,"Volume":2863700},{"Date":"2002/12/10","Open":32.35,"High":32.6,"Low":32,"Close":32.25,"Volume":3081300},{"Date":"2002/12/11","Open":32.05,"High":32.64,"Low":31.75,"Close":32.53,"Volume":3280800},{"Date":"2002/12/12","Open":32,"High":32.8,"Low":31.8,"Close":32.05,"Volume":2613900},{"Date":"2002/12/13","Open":32.05,"High":32.05,"Low":31.4,"Close":31.4,"Volume":2192500},{"Date":"2002/12/16","Open":31.27,"High":32.1,"Low":31.25,"Close":31.92,"Volume":2939600},{"Date":"2002/12/17","Open":32.06,"High":32.75,"Low":31.84,"Close":31.85,"Volume":2097500},{"Date":"2002/12/18","Open":31.77,"High":32.5,"Low":31.42,"Close":32.02,"Volume":2157700},{"Date":"2002/12/19","Open":31.73,"High":32.48,"Low":31.73,"Close":32.25,"Volume":2652000},{"Date":"2002/12/20","Open":32.92,"High":32.94,"Low":32.29,"Close":32.71,"Volume":4189000},{"Date":"2002/12/23","Open":32.71,"High":32.95,"Low":32.4,"Close":32.79,"Volume":2089400},{"Date":"2002/12/24","Open":33.5,"High":33.5,"Low":32.53,"Close":32.65,"Volume":1084500},{"Date":"2002/12/26","Open":32.85,"High":33.28,"Low":32.52,"Close":32.63,"Volume":1449300},{"Date":"2002/12/27","Open":32.9,"High":33.09,"Low":32.14,"Close":32.33,"Volume":1597200},{"Date":"2002/12/30","Open":32.33,"High":33,"Low":32.33,"Close":32.9,"Volume":2238600},{"Date":"2002/12/31","Open":32.67,"High":33.13,"Low":32.47,"Close":32.99,"Volume":2058000},{"Date":"2003/01/02","Open":33,"High":33.92,"Low":33,"Close":33.88,"Volume":2099500},{"Date":"2003/01/03","Open":34.1,"High":34.44,"Low":33.89,"Close":34.18,"Volume":2296100},{"Date":"2003/01/06","Open":34.05,"High":34.56,"Low":33.96,"Close":34.13,"Volume":2198400},{"Date":"2003/01/07","Open":34.12,"High":34.13,"Low":33.03,"Close":33.3,"Volume":2914300},{"Date":"2003/01/08","Open":33.37,"High":33.5,"Low":33.03,"Close":33.5,"Volume":3027800},{"Date":"2003/01/09","Open":33.75,"High":34.05,"Low":33.37,"Close":33.9,"Volume":2791000},{"Date":"2003/01/10","Open":33.9,"High":34.1,"Low":33.43,"Close":33.85,"Volume":3074400},{"Date":"2003/01/13","Open":34.15,"High":34.59,"Low":33.75,"Close":34.3,"Volume":3033500},{"Date":"2003/01/14","Open":34.15,"High":34.24,"Low":33.82,"Close":34.15,"Volume":1855600},{"Date":"2003/01/15","Open":34.05,"High":34.39,"Low":33.25,"Close":33.35,"Volume":2195000},{"Date":"2003/01/16","Open":33.8,"High":34.24,"Low":33.28,"Close":33.46,"Volume":2389300},{"Date":"2003/01/17","Open":33.35,"High":33.73,"Low":33.03,"Close":33.29,"Volume":2031200},{"Date":"2003/01/21","Open":33.29,"High":33.31,"Low":32.27,"Close":32.4,"Volume":2463000},{"Date":"2003/01/22","Open":32.05,"High":32.7,"Low":31.76,"Close":31.78,"Volume":3161500},{"Date":"2003/01/23","Open":31.8,"High":32.27,"Low":31.78,"Close":31.85,"Volume":2426200},{"Date":"2003/01/24","Open":31.8,"High":31.85,"Low":31,"Close":31.01,"Volume":2448300},{"Date":"2003/01/27","Open":31.05,"High":31.25,"Low":30.6,"Close":30.62,"Volume":2383700},{"Date":"2003/01/28","Open":30.74,"High":31.55,"Low":30.59,"Close":31.45,"Volume":2408600},{"Date":"2003/01/29","Open":31.46,"High":31.46,"Low":30.5,"Close":30.61,"Volume":2783000},{"Date":"2003/01/30","Open":29.97,"High":31.3,"Low":29.73,"Close":30.66,"Volume":3758500},{"Date":"2003/01/31","Open":31.11,"High":32.22,"Low":31,"Close":31.59,"Volume":3635100},{"Date":"2003/02/03","Open":30.12,"High":31.5,"Low":30.12,"Close":31.11,"Volume":3992800},{"Date":"2003/02/04","Open":30.8,"High":31.42,"Low":30.5,"Close":31.24,"Volume":3102800}];

var App = React.createClass({
  render: function() {
	  return (
		  	<KendoStockChart options={{
                    dataSource: {
                    data: dataStockChart,
                    schema: {
                        model: {
                            fields: {
                                Date: { type: "date" }
                            }
                        }
                    }
                },
                title: {
                    text: "The Boeing Company\nNYSE:BA"
                },
                dateField: "Date",
                series: [{
                    type: "candlestick",
                    openField: "Open",
                    highField: "High",
                    lowField: "Low",
                    closeField: "Close"
                }],
                categoryAxis: {
                    labels: {
                        rotation: "auto"
                    }
                },
                navigator: {
                    series: {
                        type: "area",
                        field: "Close"
                    },
                    select: {
                        from: "2009/02/05",
                        to: "2011/10/07"
                    },
                    categoryAxis: {
                        labels: {
                            rotation: "auto"
                        }
                    }
                }
			}}></KendoStockChart>
	  );
	}
});

ReactDOM.render(<App />, document.getElementById('app'));
```

## React Props

Every KUI React Wrapper can make use of the following React props:

* `options`
* `methods`
* `events`
* `unbindEvents`
* `triggerEvents`

Each is demonstrated below using a `<KendoDropDownList>` KUI React wrapper.

```javascript
<KendoDropDownList
	//only updates upon state change from above if widget supports setOptions()
	//don't define events here, do it in events prop
	options={{ //nothing new here, object of KUI configuration values
		dataSource:[{
			text: "Item1",
			value: "1"
		}, {
			text: "Item2",
			value: "2"
		}, {
			text: "Item3",
			value: "3"
		}],
		dataTextField: "text",
		dataValueField: "value"
	}}
	//updates if object is different from initial mount
	methods={{ //name of method and array of arguments to pass to method
		open:[], //send empty array if no arguments
		value:['2']
	}}
	//Right now, always updates
	events={{ //name of event, and callback
		close:function(){console.log('dropdown closed')},
		select:function(){console.log('item selected')},
		open:function(){console.log('dropdown opened')}
	}}
	//updates if array is different from initial mount
	unbindEvents={[ //name of event to unbind, string
		"select"
	]}
	//updates if array is different from initial mount
	triggerEvents={[ //name of event to trigger, string
		"open",
	]}>
		<input className="kendoDropDownList" />
</KendoDropDownList>
```

## KUI API

* StockChart demos: [http://demos.telerik.com/kendo-ui/stockchart/index](http://demos.telerik.com/kendo-ui/stockchart/index)
* StockChart docs: [http://docs.telerik.com/kendo-ui/controls/charts/stockchart/overview](http://docs.telerik.com/kendo-ui/controls/charts/stockchart/overview)
* StockChart API: [http://docs.telerik.com/kendo-ui/api/javascript/ui/stockchart](http://docs.telerik.com/kendo-ui/api/javascript/ui/stockchart)

## License

[Apache License, Version 2.0](http://www.apache.org/licenses/LICENSE-2.0)
